==> devops-client-0.2.7-sources.jar: io/alauda/devops/client/dsl/internal/CodeRepoBindingOperationsImpl.java <==
package io.alauda.devops.client.dsl.internal;

import io.alauda.devops.client.AlaudaDevOpsConfig;
import io.alauda.kubernetes.api.model.DoneableCodeRepoBinding;
import io.alauda.kubernetes.api.model.CodeRepoBinding;
import io.alauda.kubernetes.api.model.CodeRepoBindingList;
import io.alauda.kubernetes.client.dsl.Resource;
import okhttp3.OkHttpClient;

import java.util.Map;
import java.util.TreeMap;

import static io.alauda.devops.client.AlaudaAPIGroups.DEVOPS;

public class CodeRepoBindingOperationsImpl extends AlaudaOperation<CodeRepoBinding, CodeRepoBindingList, DoneableCodeRepoBinding, Resource<CodeRepoBinding, DoneableCodeRepoBinding>> {
  public CodeRepoBindingOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String namespace) {
    this(client, config, null, namespace, null, true, null, null, false, -1, new TreeMap<String, String>(), new TreeMap<String, String>(), new TreeMap<String, String[]>(), new TreeMap<String, String[]>(), new TreeMap<String, String>());
  }

  public CodeRepoBindingOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String apiVersion, String namespace, String name, Boolean cascading, CodeRepoBinding item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, AlaudaOperation.withApiGroup(client, DEVOPS, apiVersion, config), "coderepobindings", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }
}

==> devops-client-0.2.9-sources.jar: io/alauda/devops/client/dsl/internal/CodeRepoBindingOperationsImpl.java <==
package io.alauda.devops.client.dsl.internal;

import io.alauda.devops.client.AlaudaDevOpsConfig;
import io.alauda.kubernetes.api.model.DoneableCodeRepoBinding;
import io.alauda.kubernetes.api.model.CodeRepoBinding;
import io.alauda.kubernetes.api.model.CodeRepoBindingList;
import io.alauda.kubernetes.client.dsl.Resource;
import okhttp3.OkHttpClient;

import java.util.Map;
import java.util.TreeMap;

import static io.alauda.devops.client.AlaudaAPIGroups.DEVOPS;

public class CodeRepoBindingOperationsImpl extends AlaudaOperation<CodeRepoBinding, CodeRepoBindingList, DoneableCodeRepoBinding, Resource<CodeRepoBinding, DoneableCodeRepoBinding>> {
  public CodeRepoBindingOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String namespace) {
    this(client, config, null, namespace, null, true, null, "0", false, -1, new TreeMap<String, String>(), new TreeMap<String, String>(), new TreeMap<String, String[]>(), new TreeMap<String, String[]>(), new TreeMap<String, String>());
  }

  public CodeRepoBindingOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String apiVersion, String namespace, String name, Boolean cascading, CodeRepoBinding item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, AlaudaOperation.withApiGroup(client, DEVOPS, apiVersion, config), "coderepobindings", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }
}
